summaryrefslogtreecommitdiff
path: root/src/mongo/s/query/cluster_client_cursor.h
diff options
context:
space:
mode:
authorWill Buerger <will.buerger@mongodb.com>2023-05-16 20:32:42 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2023-05-17 00:09:49 +0000
commitd646e44b7801a3e5b3230bbae7dcfe05a5ed8707 (patch)
tree2eebf945a3f958e3adddc157523a49deb72cc63d /src/mongo/s/query/cluster_client_cursor.h
parent8219766da20351edcda5fe21a18da254b382cd35 (diff)
downloadmongo-d646e44b7801a3e5b3230bbae7dcfe05a5ed8707.tar.gz
SERVER-76427: Rename $telemetry to $queryStats
Co-authored-by: Ted Tuckman <ted.tuckman@mongodb.com>
Diffstat (limited to 'src/mongo/s/query/cluster_client_cursor.h')
-rw-r--r--src/mongo/s/query/cluster_client_cursor.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/s/query/cluster_client_cursor.h b/src/mongo/s/query/cluster_client_cursor.h
index 1f0d9be54a7..008bacd5ef6 100644
--- a/src/mongo/s/query/cluster_client_cursor.h
+++ b/src/mongo/s/query/cluster_client_cursor.h
@@ -270,11 +270,11 @@ public:
* Returns and releases ownership of the RequestShapifier associated with the request this
* cursor is handling.
*/
- virtual std::unique_ptr<telemetry::RequestShapifier> getRequestShapifier() = 0;
+ virtual std::unique_ptr<query_stats::RequestShapifier> getRequestShapifier() = 0;
protected:
// Metrics that are accumulated over the lifetime of the cursor, incremented with each getMore.
// Useful for diagnostics like telemetry.
OpDebug::AdditiveMetrics _metrics;
private:
@@ -270,11 +270,11 @@ public:
protected:
// Metrics that are accumulated over the lifetime of the cursor, incremented with each getMore.
- // Useful for diagnostics like telemetry.
+ // Useful for diagnostics like queryStats.
OpDebug::AdditiveMetrics _metrics;
private: